4.7. umbra.components.addons.traceUi.nodes — Umbra 1.0.9 documentation

# 4.7. umbra.components.addons.traceUi.nodes

nodes.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `umbra.components.factory.traceUi.traceUi.TraceUi` Component Interface class nodes.

Others:

## 4.7.1. Module Attributes

`umbra.components.addons.traceUi.nodes.` `LOGGER`

## 4.7.2. Classes

class `umbra.components.addons.traceUi.nodes.` `ModuleNode`(module=None, name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  Defines `umbra.components.factory.traceUi.traceUi.TraceUi` Component Interface class Module node.

  Initializes the class.

  Parameters: | module (ModuleType) – Module. name (unicode) – Node name. parent (GraphModelNode) – Node parent. children (list) – Children. roles (dict) – Roles. nodeFlags (int) – Node flags. attributesFlags (int) – Attributes flags. **kwargs (**) – Keywords arguments.

  `module`

    Property for self.__module attribute.

    Returns: | self.__module.
    Return type: | object

  `updateNodeAttributes`(attributesFlags=33)

    Updates the Node attributes.

    Parameters: | attributesFlags (int) – Attributes flags.
    Returns: | Method success.
    Return type: | bool